<?php

    namespace Modules\Master\DataTables;

    use Modules\Master\Entities\Gender;
    use Yajra\DataTables\Html\Column;
    use Yajra\DataTables\Services\DataTable;

    class GenderDataTable extends DataTable
    {
        /**
         * Build DataTable class.
         *
         * @param mixed $query Results from query() method.
         *
         * @return \Yajra\DataTables\DataTableAbstract
         */
        public function dataTable($query)
        {

            return datatables()
                ->eloquent($query)
                ->filter(function ($query) {
                    $search = request()->get('search');
                    if ($search['value'] !== "") {
                        $query->where('name', 'like', "%" . $search['value'] . "%");
                    }
                })
                ->addIndexColumn()
                ->addColumn('status', function ($model) {
                    return view('master::gender._status', compact('model'));
                })
                ->addColumn('action', function ($model) {
                    return view('master::gender._action', compact('model'));
                })
                ->rawColumns(['status','action']);
        }

        /**
         * Get query source of dataTable.
         *
         * @param \Modules\Gender\Entities\Gender $model
         *
         * @return \Illuminate\Database\Eloquent\Builder
         */
        public function query(Gender $model)
        {
            return $model->newQuery();
        }

        /**
         * Optional method if you want to use html builder.
         *
         * @return \Yajra\DataTables\Html\Builder
         */
        public function html()
        {
            return $this->builder()
                ->setTableId('master-gender-table')
                ->columns($this->getColumns())
                ->minifiedAjax()
                ->orderBy(1, 'asc')
                ->stateSave(false)
                ->responsive()
                ->autoWidth(false)
                ->parameters([
                    'scrollX'      => false,
                    'drawCallback' => 'function() { KTMenu.createInstances(); }',
                ])
                ->addTableClass('align-middle table-row-dashed fs-6 gy-5');
        }

        /**
         * Get columns.
         *
         * @return array
         */
        protected function getColumns()
        {
            return [
                Column::make('DT_RowIndex')->title('No')->orderable(false)->searchable(false),
                Column::make('name')->title(__('Name')),
                Column::computed('status')->title(__('Status'))->width(50)->addClass('text-center')->exportable(false),
                Column::computed('action')
                    ->exportable(false)
                    ->printable(false)
                    ->width(100)
                    ->addClass('text-center')
                    ->responsivePriority(-1),
            ];
        }

        /**
         * Get filename for export.
         *
         * @return string
         */
        protected function filename()
        : string
        {
            return 'Gender_' . date('YmdHis');
        }
    }