<?php

//namespace App\DataTables;
namespace Modules\Konfirmasibank\DataTables;

use Modules\Konfirmasibank\Entities\ViewAccount;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Carbon\Carbon;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;

class ViewAccountDataTable extends DataTable
{
    /**
         * Build the DataTable class.
         *
         * @param QueryBuilder $query Results from query() method.
         */
        public function dataTable(QueryBuilder $query)
        : EloquentDataTable
        {

          //  $query = $query->with(['ViewCustomer']);
            return (new EloquentDataTable($query))
                ->filter(function ($query) {
                    if (request()->has('search')) {
                        $search = request()->get('search');
                        $dataSearch = explode(',', $search['value']);
                        $query->where(function($query) use ($dataSearch){
                             if($dataSearch[0] != "" && $dataSearch[1] == "" && $dataSearch[2] == ""){
                                $query->where('CUSTOMER_NO', $dataSearch[0]);
                             } else if($dataSearch[0] != "" && $dataSearch[1] != "" && $dataSearch[2] == ""){
                                $query->where('CUSTOMER_NO', $dataSearch[0]);
                                $query->where('COMPANY_NAME', 'LIKE', "%" .  $dataSearch[1] . "%");
                             }else if($dataSearch[0] != "" && $dataSearch[1] != "" && $dataSearch[2] != ""){
                                $query->where('CUSTOMER_NO', $dataSearch[0]);
                                $query->Where('COMPANY_NAME', 'LIKE', "%" . $dataSearch[1] . "%");
                                $query->where('BATCH_DATE', 'like', "%" . Carbon::parse($dataSearch[2])->format('m'). "%" );
                             }

                        });
                    }
                })
                ->addColumn('account_number', function ($model) {
                    return $model->ACCOUNT_NUMBER;
                })
                ->addColumn('co_code', function ($model) {
                    return $model->COMPANY_NAME;
                })
                ->addColumn('product', function ($model) {
                    return $model->PRODUCT;
                })
                ->addColumn('currency', function ($model) {
                    return $model->CURRENCY;
                 })
                ->addColumn('working_balance', function ($model) {
                    return $model->WORKING_BALANCE;
                })
                ->addColumn('batch_date', function ($model) {
                    return $model->BATCH_DATE;
                })
                // ->addColumn('', function ($model) {
                //      $dt = Carbon::create($model->BATCH_DATE);
                //     return $dt->isoFormat('DD/MM/YYYY');
                // })
                ->addColumn('status', function ($model) {
                    return '<span class="badge badge-light-success">Approved</span>';
                    // if ($model->status == 1) {
                    //     return '<span class="badge badge-light-success">Approved</span>';
                    // } else if ($model->status == 0) {
                    //     return '<span class="badge badge-light-warning">Menunggu Approval</span>';
                    // } else if ($model->status == 3) {
                    //     return '<span class="badge badge-light-danger">Rejected</span>';
                    // } else if ($model->status == 4) {
                    //     return '<span class="badge badge-light-success">Approved</span> <span class="badge badge-light-warning">Request Download</span>';
                    // } else if ($model->status == 5) {
                    //     return '<span class="badge badge-light-success">Approved</span> <span class="badge badge-light-info">Download Approved</span>';
                    // } else if ($model->status == 6) {
                    //     return '<span class="badge badge-light-success">Approved</span> <span class="badge badge-light-warning">Request Delete</span>';
                    // } else if ($model->status == 7) {
                    //     return '<span class="badge badge-light-success">Approved</span> <span class="badge badge-light-danger">Request Delete</span>';
                    // } else if ($model->status == 8) {
                    //     return '<span class="badge badge-light-success">Deleted</span>';
                    // } else if ($model->status == 9) {
                    //     return '<span class="badge badge-light-success">Approved</span> <span class="badge badge-light-danger">Request Non-Aktif</span>';
                    // }
                })
                ->addIndexColumn()
                ->rawColumns(['status', 'action'])
                ->addColumn('action', 'konfirmasibank::._action')
                ->setRowId('id');
        }

        /**
         * Get the query source of dataTable.
         */
        public function query(ViewAccount $model)
        : QueryBuilder
        {
            $currentYear = Carbon::now()->format('Y');

            return $model->newQuery()->where('BATCH_DATE', 'like', "%" . $currentYear. "%");
        }

        /**
         * Optional method if you want to use the html builder.
         */
        public function html()
        : HtmlBuilder
        {
            return $this->builder()
                ->setTableId('konfirmasibank-table')
                ->columns($this->getColumns())
                ->minifiedAjax()
                ->stateSave(false)
                ->responsive()
                ->autoWidth(true)
                ->orderBy(1)
                ->parameters([
                    'scrollX'      => true,
                    'drawCallback' => 'function() { KTMenu.createInstances(); }',
                ])
                ->addTableClass('align-middle table-row-dashed fs-6 gy-5');
        }

        /**
         * Get the dataTable columns definition.
         */
        public function getColumns()
        : array
        {
            return [
                Column::make('DT_RowIndex')->title('No')->orderable(false)->searchable(false)->addClass('text-center'),
                Column::make('account_number')->title('NO Rekening')->addClass('text-center'),
                Column::make('co_code')->title('Cabang')->addClass('text-center'),
                Column::make('product')->title('Jenis Rekening')->addClass('text-center'),
                Column::make('currency')->title('Mata uang')->addClass('text-center'),
                Column::make('working_balance')->title('Saldo')->addClass('text-center'),
                Column::make('batch_date')->title('Periode')->addClass('text-center'),
               // Column::computed('status'),
                Column::computed('action')
                    ->exportable(false)
                    ->printable(false)
                    ->addClass('text-center'),
            ];
        }

        /**
         * Get the filename for export.
         */
        protected function filename()
        : string
        {
            return 'Document_' . date('YmdHis');
        }
}