<?php

    namespace Modules\Konfirmasibank\Http\Requests\Fasilitas;

    use Illuminate\Http\Exceptions\HttpResponseException;
    use Illuminate\Validation\ValidationException;
    use Illuminate\Validation\Validator;
    use Modules\Konfirmasibank\Http\Requests\MasterRequest;
    use Symfony\Component\HttpFoundation\JsonResponse;

    class StoreFasilitasRequest extends MasterRequest
    {
        /**
         * Determine if the user is authorized to make this request.
         */
        public function authorize()
        : bool
        {
            return true;
        }

        /**
         * Get the validation rules that apply to the request.
         *
         * @return array<string, \Illuminate\Contracts\Validation\Rule|array|string>
         */
        public function rules()
        : array
        {
            return [
                'nomor_rekening' => 'required|string|max:10|unique:fasilitas,nomor_rekening',
                'jenis_fasilitas' => 'required|string',
                'saldo' => 'required|string',
                'start_date' => 'required|string',
                'due_date' => 'required|string',
                'jangka_waktu' => 'required|string',
                'fixed_rate' => 'required|string'
            ];
        }

        /**
         * Configure the validator instance.
         */
        public function withValidator(Validator $validator)
        : void
        {
            $validator->after(function (Validator $validator) {
                if ($validator->errors()->any()) {
                    $errors = json_decode($validator->errors()->toJson(), true);

                    foreach ($errors as $key => $value) {
                        flash($value[0]);
                    }
                    return redirect()->route('konfirmasibank.addFasilitas')->with('error', 'Fasilitas created failed.');
                }

            });
        }

        protected function failedValidation(Validator|\Illuminate\Contracts\Validation\Validator $validator)
        : JsonResponse
        {
            $errors = (new ValidationException($validator))->errors();

            throw new HttpResponseException(response()->json([
                'success'  => false,
                'errors'   => $errors,
                'messages' => 'Fasilitas created failed.'
            ], JsonResponse::HTTP_UNPROCESSABLE_ENTITY));
        }
    }
